@@ -140,7 +140,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 internal_ctx: InternalContext,
                 context_provider: Arc<super::#server_type_name>,
             ) {
-                let subscription = internal_context.pubsub_client.subscribe(subscription_name);
+                let subscription = internal_ctx.pubsub_client.subscribe(subscription_name);
 
                 while subscription.client().is_running() {
                     match subscription.get_messages::<Message>().await {
